@@ -7,17 +7,25 @@ function (behavior,phaseX,v1,v2) {
   ctbl<-cbind(tm[,v1],tm[,v2])
   num<-ctbl[4]
   colnames (ctbl)<-c("Baselene", "Intervention")
-  nl<-c("There are", as.character(num),"values above the mean line in the intervention.")
+  pre<-(prop.table(ctbl,2)*100)
+  numpre<-pre[4]
+  nl<-c("There are", as.character(num),"value(s)","(",as.character(round(numpre,2)), "percent) above the mean line in the intervention.")
+  #nl<-c("There are", as.character(num),"value(s) above the mean line in the intervention.")
   writeLines(" ")
   writeLines("Note: Intervention TRUE values above the mean line are desired.")
   cat(sprintf(nl),"\n")
   writeLines(" ")
+  writeLines("Frequencies")
   print(ctbl)
+  
   writeLines(" ")
+  writeLines("Row Percent")
   print(prop.table(ctbl,1)*100)
   writeLines(" ")
+  writeLines("Column Percent")
   print(prop.table(ctbl,2)*100)
   writeLines(" ")
+  
   c1<-chisq.test(ctbl,simulate.p.value = TRUE)
   f1<-fisher.test(ctbl,alternative = "two.sided",conf.int = FALSE)
   print(c1)
